typedef enum  SeqModeID {

    STAND_BY,                //待機じょう
    COLD_INIT,
    HOT_INIT,
    RN4020_INIT,            //RN4020 初期設定
    RCV_ADVTISE_MODE,       //アドバタイジングパケット受信モード
    RCV_ADVTISE2_MODE,       //アドバタイジングパケット受信モード
    RCV_UDP_MES_MODE,       //UDPメッセージ受信モード

//    RCV_COMMAND_ANALYSIS,   //受信データ解析（処理はまだ入ってない？）
    CAM_CTR01,
    CAM_CTR02_ONESHOT,       //一度だけ撮影してUDPに送信する
    CAM_CTR02_CYCLE,       //一度だけ撮影してUDPに送信する
    
    RCV_UDP_MES_FROM_MASTER
    
} EM_SEQ_MODE;


#include "mbed.h"
#include "rn4020CtrMain.h"
#include "orgTimer.h"
#include "UDPctr.h"
#include "DbuffClass.h"
#include "TCPctr.h"
//
#include "CameraControl.h"
#include "common.h"
#include "SDFileSystem.h"

#include "Config.h"

#include "ipdef.h"

//関数
void    seqCtrl();
void    seq_cold_init (int locSeqNo);
void    seq_hot_init  (int locSeqNo);
void    seq_RN4020_init (int locSeqNo);
void    seq_RCV_advtise_cmd(int locSeqNo);
void    seq_RCV_advtise2_cmd(int locSeqNo);//追加
void    seq_Stand_By(int locSeqNo);
void    seq_RCV_udpMessage(int locSeqNo);

//---------------------
void    seq_CameraCtr(int locSeqNo);
void    seq_CameraCtrOneshot(int locSeqNo);  //１回撮影
void    seq_CameraCtrCycle(int locSeqNo);    //撮影繰り返しモード
//---------------------
void    seq_StandBy(int locSeqNo);


void    seq_RCV_udpMessageFromMaster(int locSeqNo);



#define IMGBUFFSIZE         (1024*100)

CameraControl   camControler;

//static char s_imagebuf1[IMGBUFFSIZE];
char s_imagebuf1[IMGBUFFSIZE];
long takpic;


SDFileSystem     s_sd(SD_MOSI_PIN, SD_MISO_PIN, SD_SCLK_PIN, SD_CS_PIN, "sd");

int pic_no = 1;
int picOne_no = 1;

Serial pc4(USBTX, USBRX); // tx, rx

//変数(外部参照
EM_SEQ_MODE seqMode;
int seqNo;

EM_SEQ_MODE seqModeNext;

bool seqChangeReqFg;

int  sendMesCounter;
int  sendPhotecounter; //カメラサイクルモードの退避条件

UDPctr  objUdp;
TCPctr  objTcp;
DbuffClass  objDbuff[MAX_RCV_BEACON];   //受信ビーコンごとの受信バッファ

static Config PeachConf;

void    seq_init()
{
    /* 電源入れ直しの場合 */

    seqMode= COLD_INIT;
    seqNo=1;
    seqChangeReqFg=false;
    seqModeNext=STAND_BY;

    pc4.baud(230400);

    pic_no=1;//写真用
    picOne_no=1; //oneshotようの通し番号
    
    sendMesCounter=0;    //マスターへの受信送信タイミング（シーケンスにのループ処理にタイマを設置する）
    sendPhotecounter=0;
    
}


void seqCtrl()
{

    switch (seqMode) {

        case COLD_INIT:
            seq_cold_init(seqNo);

            break;

        case HOT_INIT:
            seq_hot_init(seqNo);

            break;

        case RN4020_INIT:
            seq_RN4020_init(seqNo);

            break;

        case RCV_ADVTISE_MODE:
            seq_RCV_advtise_cmd(seqNo);

            break;

        case RCV_ADVTISE2_MODE:
            seq_RCV_advtise2_cmd(seqNo);        //追加
            break;

        case RCV_UDP_MES_MODE:
            seq_RCV_udpMessage(seqNo);
            break;

        case STAND_BY:
            seq_StandBy(seqNo);
            break;

        case CAM_CTR01:
            seq_CameraCtr(seqNo);
            break;
        case CAM_CTR02_ONESHOT:
            seq_CameraCtrOneshot(seqNo);
            break;
        case CAM_CTR02_CYCLE:
            seq_CameraCtrCycle(seqNo);
            break;
            
        case RCV_UDP_MES_FROM_MASTER:
            seq_RCV_udpMessageFromMaster(seqNo);
            break;
            
        default:
            break;

    }
}


void    seq_cold_init(int locSeqNo)
{

    switch(locSeqNo) {

        case 1:            //待機 x ms
            set_tim_10ms_Timer01(500);  //2000ms 待ち
            seqNo++;

            pc4.printf("INIT_SEQ_\r\n");

            camControler.init(
                CAMERA_MOSI_PIN, CAMERA_MISO_PIN,
                CAMERA_SCLK_PIN, CAMERA_CS1_PIN,
                CAMERA_SDA_PIN, CAMERA_SCL_PIN);


            break;

        case 2:            //待機 x ms
            if(read_tim_10ms_Timer01()>0) {
                break;
            }

//----------------------------------------------



//-----------------------------------------------------
//            PeachConf.SetMacAddress();  //SDから起動モードを選び設定
//    原因を究明して復活させる

            pc4.printf("INIT_SEQ2_\r\n");

            //Ether初期化処理
            objUdp.EtherOpen();
            objUdp.UDPSocketOpen();

//            seqMode = HOT_INIT;  //信号の定期受信

//            seqMode = CAM_CTR02_CYCLE;
//            seqMode = CAM_CTR02_ONESHOT;
//            seqMode = RCV_ADVTISE2_MODE;


            

//------------------------
//超暫定設 レシーバに合わせて処理を変更
//------------------------
            int defNo = (int)DEF_RECEIVER_ID_SELECT;
                        
            switch (defNo){
                case 1:
                case 2:
                    seqMode = RCV_ADVTISE2_MODE;
                    
                    break;//1,2ノーマルタイプ
                case 3://Camera type
                    seqMode = RCV_UDP_MES_FROM_MASTER;
                    break;
                
                default :            
                    seqMode = RCV_UDP_MES_FROM_MASTER;

                    break;
               
            }
    




//            
            seqNo=1;
            break;

        default:
            break;
    }

}



void    seq_hot_init(int locSeqNo)
{

    switch(locSeqNo) {

        case 1:            //待機 x ms

            pc4.printf("INIT_HOT1_\r\n");


//            sendComId =COM_ECHO_ON;     //エコーＯＮ（調整）後で消すかも

            set_tim_10ms_Timer01(300);  //3000ms 待ち
            seqNo++;
            break;
        case 2:
            if(read_tim_10ms_Timer01()>0) {
                break;
            }

            sendComId =COM_OVSERV_ROL_OFF;     //オブザーバロール停止
            set_tim_10ms_Timer01(50);  //500ms 待ち
            seqNo++;

            pc4.printf("INIT_HOT2_\r\n");

            break;

        case 3:
            if(read_tim_10ms_Timer01()>0) {
                break;
            }

            sendComId =COM_SET_FANC_A;     //セントラル設定サーバーＯＮＬＹ（設定値別途確認）
            set_tim_10ms_Timer01(50);  //500ms 待ち
            seqNo++;

            break;


        case 4:
            if(read_tim_10ms_Timer01()>0) {
                break;
            }

            sendComId =COM_SCAN_BROADCAST_B;   //アドバタイジング受信間隔設定（間隔要調整）
            set_tim_10ms_Timer01(50);  //500ms 待ち
            seqNo++;
            break;

        case 5:
            if(read_tim_10ms_Timer01()>0) {
                break;
            }

            pc4.printf("INIT_HOT5_\r\n");
            sendComId =COM_REBOOT;              //アドバタイジング受信間隔設定（間隔要調整）
            set_tim_10ms_Timer01(1000);  //1000ms 待ち 待ち
            seqNo++;

            break;

        case 6:
            if(read_tim_10ms_Timer01()>0) {
                break;
            }
            pc4.printf("INIT_HOT6_\r\n");

            sendComId =COM_ECHO_ON;              //アドバタイジング受信間隔設定（間隔要調整）
            set_tim_10ms_Timer01(50);             //500ms 待ち
            seqNo++;

            break;

        case 7:
            if(read_tim_10ms_Timer01()>0) {
                break;
            }

            sendComId =COM_OVSERV_ROL_OFF;              //アドバタイジング受信間隔設定（間隔要調整）
            set_tim_10ms_Timer01(50);             //500ms 待ち
            seqNo++;

            break;

        case 8:
            if(read_tim_10ms_Timer01()>0) {
                break;
            }

            pc4.printf("INIT_HOT8_\r\n");

            seqMode = RCV_ADVTISE_MODE;  //アドバタイジングパケット受信モードへ
            seqNo=1;

            break;


        default:
            break;

    }

}

void    seq_RN4020_init(int locSeqNo)
{

    switch(locSeqNo) {
        case 1:
        default:
            break;

    }

}


void    seq_RCV_advtise_cmd(int locSeqNo)
{

    switch(locSeqNo) {
        case 1: {
            
//            printf("SET CAMERA  MODE OFF\r\n");     //一旦カメラモードをOFFに ★いくつかいれる

//            objUdp.SLVsendUDPcomCamSet(comKeyCamOff);  
            
            
            FgAdvRcvOn=true; //バッファへの退避を停止

            sendComId =COM_OVSERV_ROL_ON;        //アドバタイジング受信開始（設定Ｂ）

            set_tim_10ms_Timer01(300);  //3000ms 待ち
            seqNo++;

            pc4.printf("ADV_1_\r\n");

            break;
        }
        case 2: {
            if(read_tim_10ms_Timer01()>0) {
                break;
            }
            printf("SET RECEIVE MODE ON\r\n");      //一旦受信モード  ONに ★いくつかいれる
            objUdp.SLVsendUDPcomCamSet(comKeyRcvOn);   

            sendComId =COM_SCAN_BROADCAST_B;   //ブロードキャスト受信開始
            set_tim_10ms_Timer01(1000);  //100000ms 待ち
            seqNo++;

            pc4.printf("ADV_2_\r\n");

            break;
        }
        //受信コマンド解析処理
        case 3:{
            if(read_tim_10ms_Timer01()<1000) {
                FgAdvRcvOn=true;                //バッファへの退避を有効にする
            }
            if(read_tim_10ms_Timer01()>0) {
                break;
            }

//            FgAdvRcvOn=false; //バッファへの退避を無効にする

            //受信データの解析処理

            sendComId =COM_STOP_BROAD_RCV;   //X ブロードキャスト受信停止
            set_tim_10ms_Timer01(50);       //500ms 待ち
            seqNo++;

            //TEST
            BEACON_RCV_ENAVLE[RCV_BEACON01][0]=false;//受信フラグをいったんOFF
            BEACON_RCV_ENAVLE[RCV_BEACON01][1]=false;//受信フラグをいったんOFF
            BEACON_RCV_ENAVLE[RCV_BEACON01][2]=false;//受信フラグをいったんOFF


            FgUnitySendOn=true;//RN4020の受信データのシリアル送信を止める
            pc4.printf("ADV_3_\r\n");

            break;
        }
        case 4:{
            if(read_tim_10ms_Timer01()>0) {
                break;
            }

            FgAdvRcvOn=false; //が正解の気がする

            char s2[] = ",";

            for(int i=0; i<MAX_WordSize; i++) {

                char *tok;
                int checkBeacon=0;
                int counter_ii=0;  //トークン位置カウンタ

                bool machBeaconID=false;

                tok=strtok(&rcvDataBuff[i][0],s2);

                while(tok != NULL) {

                    //レシーバー01 固定で対応
                    //処理方法は決め打ちです
                    if(counter_ii==0) {

                        for(int x=0; x<BeconNum; x++) {

                            char strBuffer[13];
                            get_BeaconMacID(x,strBuffer);

                            if(strncmp(tok,strBuffer,BEACON_ID_SIZE)==0) {
                                machBeaconID=true;
                                checkBeacon=x;

                                pc4.printf("TOK1=%s\r\n",&BEACON_ID[checkBeacon][0]);
                                strncpy(&BEACON_ID[checkBeacon][0],tok,BEACON_ID_SIZE);

                                pc4.printf("TOK2=%s\r\n",tok);
                                pc4.printf("TOK3=%s\r\n",&BEACON_ID[checkBeacon][0]);

                                break;
                            }
                        }

                        if(machBeaconID==false) {
                            break;
                        }


                    } else if(counter_ii==2) {

                        pc4.printf("TOK12=%s\r\n",&BEACON_RSSI[checkBeacon][0]);

                        strncpy(&BEACON_RSSI[checkBeacon][0],tok,BEACON_RSSI_SIZE);
                        BEACON_RCV_ENAVLE[RCV_BEACON01][checkBeacon]=true;

                        //暫定処置無理やりNULLを突っ込んでいる。
                        BEACON_RSSI[checkBeacon][BEACON_RSSI_SIZE-1]=NULL;

                        pc4.printf("TOK13=%s\r\n",tok);
                        pc4.printf("TOK14=%s\r\n",&BEACON_RSSI[checkBeacon][0]);

                    } else {

                    }
                    counter_ii++;
                    tok= strtok(NULL,s2);

                }

            }


            seqNo++;
            pc4.printf("ADV_4_\r\n");

            set_tim_10ms_Timer01(50);       //500ms 待ち
            break;
        }
        case 5:
        {
            if(read_tim_10ms_Timer01()>0) {
                break;
            }

            pc4.printf("ADV_5_\r\n");
            seqNo++;

            //Pcにコマンド送信
            //BEACON ID＋RSSIを送信

            //処理が追いつくか心配だが暫定は一気に送信することにする

            for(int loop=0; loop<BeconNum; loop++) {
                if(BEACON_RCV_ENAVLE[RCV_BEACON01][loop]==true) {

                    pc4.printf("FFFFFF");                               //キーコード
                    pc4.printf("\t");           //    区切り文字
                    pc4.printf("%s",RECEIVER01_ID);                     //レシーバID  (これは固定）
                    pc4.printf("\t");           //    区切り文字
                    pc4.printf("%s",&BEACON_ID[loop][0]);                //受信ビーコンID
                    pc4.printf("\t");           //区切り文字
                    pc4.printf("%s",&BEACON_RSSI[loop][0]);
                    pc4.printf("\r\n");                                  //Unity 向けの改行コードは\r\n そこまでのデータを１つのメッセージとするみたい


                    wait_ms(500);   //早すぎるとUNITY側のフラグ処理が追いつかないで取りこぼす。。。
                    //改造するまではこのおまじないが必要

                    //スレーブビーコン用受信バッファにデータ格納
                    objDbuff[loop].setRSSInow(&BEACON_RSSI[loop][0]);//指定ビーコンバッファに取得RSSI値を格納

                } else {
                    //信号未受信時への対応
                    objDbuff[loop].setRSSInow(NULL);//指定ビーコンバッファに取得RSSI値を格納
                }


            }

            set_tim_10ms_Timer01(50);       //500ms 待ち
            break;
        }
        case 6:
        {
            if(read_tim_10ms_Timer01()>0) {
                break;
            }

            FgUnitySendOn=true;

            sendMesCounter=11;           //10以上を設定すればOneShotで待機状態に
            seqMode = RCV_UDP_MES_MODE;  //UDP送信関数
            seqNo=1;
            break;
        }
        default:
            break;

    }
}



void    seq_Stand_By(int locSeqNo)
{
    switch(locSeqNo) {

        case 1:            //待機 x ms
        default:
            break;

    }
}

//--------------------
//--------------------
//ビーコン受信サイクルモード
void    seq_RCV_advtise2_cmd(int locSeqNo)
{

    switch(locSeqNo) {
        case 1: {

            
            
            FgAdvRcvOn=true; //バッファへの退避開始

            //            sendComId =COM_OVSERV_ROL_ON;        //アドバタイジング受信開始（設定Ｂ）
            //            set_tim_10ms_Timer01(300);  //3000ms 待ち
            // コマンド送信なしの場合
            set_tim_10ms_Timer01(10);  //100ms 待ち

            seqNo++;

            break;
        }
        case 2: {
            if(read_tim_10ms_Timer01()>0) {
                break;
            }

//------------------------
//超暫定設 レシーバに合わせて処理を変更
//------------------------
            int defNo = (int)DEF_RECEIVER_ID_SELECT;
                        
            switch (defNo){
                case 1:
                case 2:                    
                    break;//1,2ノーマルタイプ
                case 3://Camera type
                    printf("SET RECEIVE MODE ON\r\n");      //一旦受信モード  ONに ★いくつかいれる
                    objUdp.SLVsendUDPcomCamSet(comKeyRcvOn);   
                    break;
                
                default :            
                    seqMode = RCV_UDP_MES_FROM_MASTER;
                    break;
               
            }


            sendComId =COM_SCAN_BROADCAST_B;   //ブロードキャスト受信開始
            set_tim_10ms_Timer01(400);  //2500ms 待ち
            seqNo++;

            break;
        }
        //受信コマンド解析処理
        case 3:
        {
//            if(read_tim_10ms_Timer01()<400) {   //注意うえいじったらここもいじる
//                FgAdvRcvOn=true;                //バッファへの退避を有効にする
//            }
            if(read_tim_10ms_Timer01()>0) {
                break;
            }

//            FgAdvRcvOn=false; //バッファへの退避を無効にする

            //受信データの解析処理

            sendComId =COM_STOP_BROAD_RCV;   //X ブロードキャスト受信停止
            set_tim_10ms_Timer01(50);        //500ms 待ち
            seqNo++;

            //TEST
            BEACON_RCV_ENAVLE[RCV_BEACON01][0]=false;//受信フラグをいったんOFF
            BEACON_RCV_ENAVLE[RCV_BEACON01][1]=false;//受信フラグをいったんOFF
            BEACON_RCV_ENAVLE[RCV_BEACON01][2]=false;//受信フラグをいったんOFF

            FgUnitySendOn=true;//RN4020の受信データのシリアル送信を止める

            break;
        }
        case 4:
        {
            if(read_tim_10ms_Timer01()>0) {
                break;
            }

            FgAdvRcvOn=false; //が正解の気がする


            char s2[] = ",";

            for(int i=0; i<MAX_WordSize; i++) {

                char *tok;
                int checkBeacon=0;
                int counter_ii=0;  //トークン位置カウンタ

                bool machBeaconID=false;

                tok=strtok(&rcvDataBuff[i][0],s2);

                while(tok != NULL) {

                    //レシーバー01 固定で対応
                    //処理方法は決め打ちです
                    if(counter_ii==0) {

                        for(int x=0; x<BeconNum; x++) {

                            char strBuffer[13];
                            get_BeaconMacID(x,strBuffer);

                            if(strncmp(tok,strBuffer,BEACON_ID_SIZE)==0) {
                                machBeaconID=true;
                                checkBeacon=x;

                                strncpy(&BEACON_ID[checkBeacon][0],tok,BEACON_ID_SIZE);

                                break;
                            }
                        }

                        if(machBeaconID==false) {
                            break;
                        }


                    } else if(counter_ii==2) {


                        strncpy(&BEACON_RSSI[checkBeacon][0],tok,BEACON_RSSI_SIZE);
                        BEACON_RCV_ENAVLE[RCV_BEACON01][checkBeacon]=true;

                        //暫定処置無理やりNULLを突っ込んでいる。
                        BEACON_RSSI[checkBeacon][BEACON_RSSI_SIZE-1]=NULL;


                    } else {

                    }
                    counter_ii++;
                    tok= strtok(NULL,s2);

                }

            }

            seqNo++;
            set_tim_10ms_Timer01(50);       //500ms 待ち
            break;
        }
        
        case 5:
        {
            if(read_tim_10ms_Timer01()>0) {
                break;
            }

            seqNo++;

            //Pcにコマンド送信
            //BEACON ID＋RSSIを送信

            //処理が追いつくか心配だが暫定は一気に送信することにする

            for(int loop=0; loop<BeconNum; loop++) {
                if(BEACON_RCV_ENAVLE[RCV_BEACON01][loop]==true) {
                    wait_ms(50);

                    //スレーブビーコン用受信バッファにデータ格納
                    objDbuff[loop].setRSSInow(&BEACON_RSSI[loop][0]);//指定ビーコンバッファに取得RSSI値を格納

                } else {
                    //信号未受信時への対応
                    objDbuff[loop].setRSSInow(NULL);//指定ビーコンバッファに取得RSSI値を格納
                }

            }

            set_tim_10ms_Timer01(50);       //500ms 待ち
            break;
        }
        case 6:
        {
            if(read_tim_10ms_Timer01()>0) {
                break;
            }

            seqMode = RCV_UDP_MES_MODE;  //UDP送信関数
            seqNo=1;
            break;
        }
        default:
            break;

    }
}






//--------------------

void    seq_RCV_udpMessage(int locSeqNo)
{//マスターへのメッセージ送信（名前がおかしい）

    switch(locSeqNo) {
        case 1:
        {
            FgUnitySendOn=true;

            char stBf00[BEACON_RSSI_SIZE];
            char stBf01[BEACON_RSSI_SIZE];
            char stBf02[BEACON_RSSI_SIZE];

            bool b0=objDbuff[RCV_BEACON01].getCopyRSSInow(stBf00);
            bool bl=objDbuff[RCV_BEACON02].getCopyRSSInow(stBf01);
            bool b2=objDbuff[RCV_BEACON03].getCopyRSSInow(stBf02);


            /*
            printf("A %s\r\n",&stBf00[0]);
            printf("B %s\r\n",&stBf01[0]);
            printf("C %s\r\n",&stBf02[0]);
            */

            

            objUdp.SLVsendUDPcom( stBf00
                                 ,stBf01
                                 ,stBf02
                                );




            set_tim_10ms_Timer01(10);  //100ms 待ち
            seqNo++;
            break;
        }
        case 2:
        {
            if(read_tim_10ms_Timer01()>0) {
                break;
            }

            sendMesCounter++;        //受信信号メッセージをマスターに送信した回数
            
//------------------------
//超暫定設 レシーバに合わせて処理を変更
//------------------------
            int defNo = (int)DEF_RECEIVER_ID_SELECT;                      
            switch (defNo){
                case 1:
                case 2:          
                    seqMode =RCV_ADVTISE2_MODE;
                    seqNo=1;           
                    break;//1,2ノーマルタイプ
                case 3://Camera type
                    if(sendMesCounter > 10){
                        //5s*10(約50s程度)
                        seqMode =RCV_UDP_MES_FROM_MASTER;  //マスターメッセージ待機モードに★
                        seqNo=1;
                        sendMesCounter=0;        //受信信号メッセージをマスターに送信した回数
                        
        
                        printf("SET RECEIVE MODE OFF\r\n");     //受信モードを  OFFに ★いくつかいれる
                        objUdp.SLVsendUDPcomCamSet(comKeyRcvOff);  
                        
                        
                    }else{
                        seqMode =RCV_ADVTISE2_MODE;  //常時監視モードに
                        seqNo=1;                
                    }
                    break;                
                default :            
                    break;               
            }
            break;            
        }
        default :
            break;
    }
}

void    seq_CameraCtr(int locSeqNo)
{

    switch(locSeqNo) {
        case 1:
            
            takpic=camControler.takePicture(s_imagebuf1,sizeof(s_imagebuf1));
            printf("Take Pictuer %s\r\n",takpic);
            printf("TEST0\r\n");


            set_tim_10ms_Timer01(100);  //50ms 待ち
            seqNo++;
            break;
        case 2: {
            if(read_tim_10ms_Timer01()>0) {
                break;
                printf("TEST0.1\r\n");

            }

            char filename[32];

            printf("TEST1\r\n");
            mkdir("/sd/image", 0777);
            printf("TEST2\r\n");
            snprintf(filename, sizeof(filename), "/sd/image/pict%04d-1.jpg", pic_no);

            FILE *outFile1;
            outFile1 = fopen(filename, "w");

            printf("file Name = %s \r\n",filename);
            printf("file open result = %s \r\n",outFile1);
            if(outFile1 != NULL) {
                fwrite(s_imagebuf1,takpic,1,outFile1);
                fclose(outFile1);
                printf( "CAM1 FILESAVE DONE. filename=%s, len=%d\r\n", filename, takpic);
            }

            printf("TEST3");
            seqNo++;
            break;
        }

        case 3: {
            if(read_tim_10ms_Timer01()>0) {
                break;
            }

            printf("TEST4");

            char filename2[32];
            mkdir("/sd/info", 0777);

            snprintf(filename2, sizeof(filename2), "/sd/info/pict%04d-1.txt", pic_no);

            FILE *outFile2;
            outFile2 = fopen(filename2, "w");

            printf("file Name = %s \r\n",filename2);
            printf("file open result = %s \r\n",outFile2);
            if(outFile2 != NULL) {

                fprintf(outFile2,"192.168.1.200\r\n");
                fprintf(outFile2,"255.255.255.0\r\n");
                fprintf(outFile2,"192.168.1.200\r\n\0");

                fclose(outFile2);
                printf( "IP WRITE TEXT. filename=%s\r\n", filename2);
            }

            seqNo++;
            break;
        }

        case 4: {
            if(read_tim_10ms_Timer01()>0) {
                break;
            }

            char filename3[32];
            snprintf(filename3, sizeof(filename3), "/sd/info/pict%04d-1.txt", pic_no);

            FILE *outFile3;
            outFile3 = fopen(filename3, "r");

            printf("************file Write");
            printf("file Name = %s \r\n",filename3);
            printf("file open result = %s \r\n",outFile3);

            if(outFile3 != NULL) {

                char ltext[32];
                //fscanfはエラーの場合参照位置が変わらないらしい
                //よってエラー処理がないと無限ループの可能性がある
                while( fgets( ltext, 32,outFile3 ) != NULL ) {
                    printf("read=%s\r\n",ltext);
                }

                fclose(outFile3);

                printf("fileEND\r\n");
            }


            //----------------------------------------------
            mkdir("/sd/config", 0777);

            FILE *outFile5;
            outFile5 = fopen("/sd/config/macaddress.txt", "r");
            //    outFile = fopen(filename, "r");

            printf("File Read [/sd/config/macaddress.txt]\r\n");
            printf("file open result = %p \r\n",outFile5);

            //基本的に正しいフォーマット前提
            if(outFile5 != NULL) {

                char readText[32];
                while( fgets( readText, 32,outFile5 ) != NULL ) {

//                    analyzeMacAddress(readText);
                    //読み出したデータを設定
                    printf("read=%s\r\n",readText);
                }

                fclose(outFile5);

                printf("fileEND\r\n");
            }

            pic_no++;
            seqNo=1;
            break;
        }


        default :
            break;
    }

}

//一度だけ撮影するモード
void    seq_CameraCtrOneshot(int locSeqNo){
    switch(locSeqNo) {
        case 1:{
            
            takpic=camControler.takePicture(s_imagebuf1,sizeof(s_imagebuf1));
            printf("Take Pictuer One Shot %d\r\n",takpic);

            set_tim_10ms_Timer01(100);  //1000ms 待ち
            seqNo++;
            break;
        }
        
        case 2: {
            if(read_tim_10ms_Timer01()>0) {
                break;
            }
            
            printf("stack1\r\n");
            printf("%d\n", DEFAULT_STACK_SIZE);
            
            //--------------------------------------            
            // TCPorUDP に送信
            //--------------------------------------            

            objUdp.SLVsendUDPcomData(s_imagebuf1,takpic);

            
/*
            objTcp.TCPSendPhote(&objUdp.net,s_imagebuf1,takpic);
            //送信制限の謎解明できず今後究明
            
*/          
            picOne_no++;            
            seqNo++;
            set_tim_10ms_Timer01(100);

            break;
        }


        case 3: {
            if(read_tim_10ms_Timer01()>0) {
                break;
            }

            char filename[32];

            mkdir("/sd/image", 0777);
            snprintf(filename, sizeof(filename), "/sd/image/one_pict%04d-1.jpg", picOne_no);

            FILE *outFile1;
            outFile1 = fopen(filename, "w");

            printf("file Name = %s \r\n",filename);
            printf("file open result = %s \r\n",outFile1);
            if(outFile1 != NULL) {
                fwrite(s_imagebuf1,takpic,1,outFile1);
                fclose(outFile1);
                printf( "CAM1 FILESAVE DONE. filename=%s, len=%d\r\n", filename, takpic);
            }

            printf("TEST3");
            seqNo++;
            set_tim_10ms_Timer01(100);

            break;
        }

        case 4: {
            if(read_tim_10ms_Timer01()>0) {
                break;
            }
            printf("send END \r\n");
            seqMode = RCV_UDP_MES_FROM_MASTER;  //スタンバイモードへ★★
            seqNo=1;
            
            printf("SET CAMERA  MODE OFF\r\n");     //一旦カメラモードをOFFに ★いくつかいれる
            objUdp.SLVsendUDPcomCamSet(comKeyCamOff);  
            
            
            break;
        }
        default :
            break;
    }

}
        
void    seq_CameraCtrCycle(int locSeqNo)
{

    switch(locSeqNo) {
        case 1:
            //撮影----------------
            takpic=camControler.takePicture(s_imagebuf1,sizeof(s_imagebuf1));
            printf("Take Pictuer Cycle %d\r\n",takpic);

            set_tim_10ms_Timer01(100);  //100ms 待ち
            seqNo++;
            break;
        case 2: {

            if(read_tim_10ms_Timer01()>0) {

                break;

            }

            printf("===================\r\n");
            //--------------------------------------            
            // UDP に送信
            //--------------------------------------            
            objUdp.SLVsendUDPcomData(s_imagebuf1,takpic);

            set_tim_10ms_Timer01(10);  //100ms 待ち
            
//            wait_ms(500);
//            for(int i=0;i<takpic;++i){
//                printf("%d",s_imagebuf1[i]);
//            }
            
            pic_no++;
            seqNo++;
            break;
        }

        case 3: {
            if(read_tim_10ms_Timer01()>0) {
                break;
            }

            //--------------------------------------            
            // SDカードに保存
            //--------------------------------------            
            char filename[32];

            mkdir("/sd/image", 0777);
            printf("TEST2\r\n");
            snprintf(filename, sizeof(filename), "/sd/image/pict%04d-1.jpg", pic_no);

            FILE *outFile1;
            outFile1 = fopen(filename, "w");

            printf("file Name = %s \r\n",filename);
//            printf("file open result = %s \r\n",outFile1);
            if(outFile1 != NULL) {
                fwrite(s_imagebuf1,takpic,1,outFile1);
                fclose(outFile1);
                printf( "CAM1 FILESAVE DONE. filename=%s, len=%d\r\n", filename, takpic);
            }            

/* 一旦封印
            if(seqChangeReqFg==true){
            //モード遷移割込みありの時は要求シーケンスに抜ける。
                seqMode = seqModeNext;
            }else{
            //サイクル撮影モード継続
                //シークモードキープ
            }
*/
            
            sendPhotecounter++;
            if(sendPhotecounter >10){
                seqMode=RCV_UDP_MES_FROM_MASTER;    //マスターメッセージ受信待ちモードへ
                sendPhotecounter=0;               //★★
                seqNo=1;
                
                printf("SET CAMERA  MODE OFF\r\n");     //一旦カメラモードをOFFに ★いくつかいれる
                objUdp.SLVsendUDPcomCamSet(comKeyCamOff);  
                

            }else{
                seqNo=1;
                //カメラサイクルモードを継続
            }
            
            
            break;
        }
        default :
            break;
    }

}


void  seq_RCV_udpMessageFromMaster(int locSeqNo)
{

    switch(locSeqNo) {
        case 1:                
        {
            if(read_tim_10ms_Timer01()>0) {
                break;
            }
            



            printf("Waiting Now Master Message received ");
            int rslt = objUdp.SLVrcvUDPcom();
            
            if(rslt ==0){
                seqMode = RCV_ADVTISE2_MODE;
                seqNo=1;
                printf("adv2 mode\r\n");
                //ビーコン受信待機モードへ
                //カメラOFF指示を受けたとき
                
            }else if(rslt == 1){
                seqMode = CAM_CTR02_CYCLE;
                seqNo=1;
                printf("camCycle mode\r\n");

                //カメラ撮影待機モードへ
                
            }else {
                  seqNo++;//処理継続

            }
            
            set_tim_10ms_Timer01(10);  //100ms 待ち

            
            break;
        }    
        case 2:
        {
            if(read_tim_10ms_Timer01()>0) {
                break;
            }
            seqNo   = 1;
            break;
        }
        case 3:
            break;            
        default :            
            seqNo   = 1; //重複だけどOK
            break;
    }    
}


void    seq_StandBy(int locSeqNo){
    
    switch(locSeqNo) {
        case 1:
        default :            
            if(seqChangeReqFg==true){
                seqChangeReqFg=false;       //このフラグは制御メッセージ受信の中でしか使ったらあかん
                seqMode = seqModeNext;
                seqNo   = 1;                //重複だけどOK（万一Caeeが増えた場合に備える）
                seqModeNext=STAND_BY;
            }

            seqNo   = 1; //重複だけどOK
            break;
    }
    
    
}



